@@ -7,6 +7,12 @@ class DBBaseConnector(BaseConnector):
     def __init__(self):
         super().__init__()
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        pass
+
     @abstractmethod
     def get_pandas_df(self, query, verbose_output):
         """Get Pandas dataframe
