@@ -6,13 +6,15 @@ from dataverk.connectors.abc.db_base import DBBaseConnector
 class SQLiteConnector(DBBaseConnector):
 
     def __init__(self, source=":memory:"):
-        """Init"""
-
         super().__init__()
+
         self.source = source
         self.cnx = sqlite3.connect(self.source)
         self.cur = self.cnx.cursor
 
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.cnx.close()
+
     def get_pandas_df(self, query, verbose_output=False):
         """Get Pandas dataframe"""
 
@@ -21,8 +23,8 @@ class SQLiteConnector(DBBaseConnector):
 
         return pd.read_sql_query(query, self.cnx)
     
-    def persist_pandas_df(self, table, schema=None, df=None, chunksize=10000, if_exists='replace'):
+    def persist_pandas_df(self, table, schema=None, df=None, chunksize=10000, if_exists='append'):
         """Persist Pandas dataframe"""
         
         # TODO try catch
-        df.to_sql(table, self.cnx, if_exists="replace")
+        df.to_sql(table, self.cnx, if_exists=if_exists)
